{% for commit in ctx %}
{{ commit.hash }} | {{ commit.msg }}
{{ commit.author_date }} | {{ commit.author_name }}
{{ commit.branches }}
Added lines:    {{ "%5d"|format(commit.added)  }}
Deleted lines:  {{ "%5d"|format(commit.deleted) }}
Changed files:  {{ "%5d"|format(commit.changed_files) }}
{% endfor %}
